@@ -69,9 +69,10 @@ def get_dir_info_exceptions(directory: str) -> DirInfo:
         others = [_ for _ in allchanges if not _.endswith(".py")]
         py_dirty = len(pyfiles) > 0
 
-        if not py_dirty and di.dirty:
-            msg = "Python package detected. Ignoring non-python file changes."
-            logger.info(msg, ignored=others)
+        if (not py_dirty) and di.dirty:
+            if others:
+                msg = "Python package detected. Ignoring non-python file changes."
+                logger.info(msg, ignored=others)
         di.dirty = py_dirty
     else:
         allchanges = di.modified + di.deleted + di.added
